import { LinkedRenderStore } from "./LinkedRenderStore";
import { linkMiddleware } from "./linkMiddleware";
function applyMiddleware(lrs, ...layers) {
    const storeBound = layers.map((middleware) => middleware(lrs));
    const finish = (a, _o) => Promise.resolve(a);
    return storeBound.reduceRight((composed, f) => {
        const next = f(composed);
        if (!next) {
            throw new Error("Provided middleware did not return handler.");
        }
        return next;
    }, finish);
}
/**
 * Initializes a {LinkedRenderStore} with tied together middleware.
 * @param storeOpts Constructor arguments for the LRS.
 * @param middleware Main middleware, to be executed before the {linkMiddleware}.
 * @param trailingMiddleware Middleware to be placed after the {linkMiddleware}. Note: defining trailing middleware
 *  causes actions not to be executed via {LinkedRenderStore#execActionByIRI} anymore, this behaviour can be enabled
 *  manually in one of the defined middlewares if still desired.
 */
export function createStore(storeOpts = {}, middleware = [], trailingMiddleware = []) {
    const LRS = new LinkedRenderStore(storeOpts);
    LRS.dispatch = applyMiddleware(LRS, ...middleware, linkMiddleware(trailingMiddleware.length === 0), ...trailingMiddleware);
    return LRS;
}
