import rdfFactory, { Feature } from "@ontologies/core";
export const createEqualComparator = (factory) => factory.supports[Feature.identity]
    ? (a, b) => a === b
    : factory.supports[Feature.idStamp]
        ? (a, b) => a?.id === b?.id
        : (a, b) => factory.equals(a, b);
/** @internal */
export const equals = createEqualComparator(rdfFactory);
const noIdError = (obj) => {
    throw new TypeError(`Factory has idStamp feature, but the property wasn't present on ${obj}`);
};
const noValueError = (obj) => {
    throw new TypeError(`Unable to lookup property 'value' on ${obj}.`);
};
/** @internal */
export const id = rdfFactory.supports[Feature.idStamp]
    ? (obj) => obj?.id || noIdError(obj)
    : (obj) => rdfFactory.id(obj);
/** @internal */
export const value = (obj) => obj?.value ?? noValueError(obj);
export const idToValue = (recordId) => {
    if (recordId.includes(":") && !recordId.startsWith("_:")) {
        return rdfFactory.namedNode(recordId);
    }
    else {
        return rdfFactory.blankNode(recordId);
    }
};
