export class RequestInitGenerator {
    constructor(opts = {}) {
        this.baseHeaders = opts.headers || {};
        this.csrfFieldName = opts.csrfFieldName ?? "csrf-token";
        this.credentials = opts.credentials ?? "include";
        this.mode = opts.mode ?? "same-origin";
        this.xRequestedWith = opts.xRequestedWith ?? "XMLHttpRequest";
    }
    authenticityHeader(options = {}) {
        return Object.assign({}, options, {
            "X-CSRF-Token": this.getAuthenticityToken(),
            "X-Requested-With": this.xRequestedWith,
        });
    }
    generate(method = "GET", accept = "text/turtle", body) {
        const isFormEncoded = body instanceof URLSearchParams;
        const headers = this.getHeaders(accept);
        if (isFormEncoded) {
            headers["Content-Type"] = "application/x-www-form-urlencoded; charset=UTF-8";
        }
        return {
            body: isFormEncoded ? body.toString() : body,
            credentials: this.credentials,
            headers,
            method: method.toUpperCase(),
            mode: this.mode,
        };
    }
    getHeaders(accept) {
        const acceptHeader = Object.assign({}, this.baseHeaders, { Accept: accept });
        if (this.credentials === "include" || this.credentials === "same-origin") {
            return this.authenticityHeader(acceptHeader);
        }
        return acceptHeader;
    }
    getMetaContent(name) {
        const header = document.head && document.head.querySelector(`meta[name="${name}"]`);
        return header && header.getAttribute("content");
    }
    getAuthenticityToken() {
        return this.getMetaContent(this.csrfFieldName) || "";
    }
}
