import { RecordState } from "./RecordState";
const doc = (recordId) => {
    return recordId.split("#")[0];
};
const absentStatus = {
    current: RecordState.Absent,
    lastUpdate: -1,
    previous: RecordState.Absent,
};
// tslint:disable member-ordering
export class RecordJournal {
    constructor(onChange, data) {
        this.data = {};
        this.onChange = () => undefined;
        this.onChange = onChange;
        if (data) {
            this.data = data;
        }
    }
    copy(onChange = null) {
        return new RecordJournal(onChange ?? this.onChange, JSON.parse(JSON.stringify(this.data)));
    }
    /**
     * Get the [RecordStatus] for the [recordId].
     * Will return an invalid status when passing a local id.
     */
    get(recordId) {
        return this.data[doc(recordId)] ?? absentStatus;
    }
    touch(recordId) {
        const docId = doc(recordId);
        if (this.data[docId] === undefined) {
            this.data[docId] = {
                current: RecordState.Absent,
                lastUpdate: Date.now(),
                previous: RecordState.Absent,
            };
        }
        else {
            this.data[docId].lastUpdate = Date.now();
        }
        this.onChange(docId);
        this.onChange(recordId);
    }
    transition(recordId, state) {
        const docId = doc(recordId);
        const existing = this.data[docId];
        const previous = existing !== undefined
            ? existing.current
            : RecordState.Absent;
        this.data[docId] = {
            current: state,
            lastUpdate: Date.now(),
            previous,
        };
        this.onChange(docId);
        if (docId !== recordId) {
            this.onChange(recordId);
        }
    }
}
