import rdfFactory, { QuadPosition, } from "@ontologies/core";
import { equals } from "../factoryHelpers";
const matchSingle = (graphIRI) => {
    const value = graphIRI.value;
    return (graph) => equals(graph, graphIRI) || graph.value.startsWith(value);
};
const isInGraph = (graphIRIS) => {
    if (graphIRIS.length === 0) {
        throw new Error("Pass a default graph explicitly");
    }
    const matchers = graphIRIS.map((iri) => matchSingle(iri));
    return (graph) => matchers.some((matcher) => matcher(graph));
};
const pushQuadruple = (arr, quadruple, graph) => {
    arr.push([
        quadruple[QuadPosition.subject],
        quadruple[QuadPosition.predicate],
        quadruple[QuadPosition.object],
        graph,
    ]);
};
export const deltaProcessor = (addGraphIRIS, replaceGraphIRIS, removeGraphIRIS, purgeGraphIRIS, sliceGraphIRIS) => {
    const defaultGraph = rdfFactory.defaultGraph();
    const isAdd = isInGraph(addGraphIRIS);
    const isReplace = isInGraph(replaceGraphIRIS);
    const isRemove = isInGraph(removeGraphIRIS);
    const isPurge = isInGraph(purgeGraphIRIS);
    const isSlice = isInGraph(sliceGraphIRIS);
    return (store) => (delta) => {
        const addable = [];
        const replaceable = [];
        const removable = [];
        for (const quad of delta) {
            if (!quad) {
                continue;
            }
            const g = new URL(quad[QuadPosition.graph].value).searchParams.get("graph");
            const graph = g ? rdfFactory.termFromNQ(g) : defaultGraph;
            if (isAdd(quad[QuadPosition.graph])) {
                pushQuadruple(addable, quad, graph);
            }
            else if (isReplace(quad[QuadPosition.graph])) {
                pushQuadruple(replaceable, quad, graph);
            }
            else if (isRemove(quad[QuadPosition.graph])) {
                removable.push(...store.match(quad[QuadPosition.subject], quad[QuadPosition.predicate], null));
            }
            else if (isPurge(quad[QuadPosition.graph])) {
                removable.push(...store.match(quad[QuadPosition.subject], null, null));
            }
            else if (isSlice(quad[QuadPosition.graph])) {
                removable.push(...store.match(quad[QuadPosition.subject], quad[QuadPosition.predicate], quad[QuadPosition.object]));
            }
        }
        return [
            addable,
            replaceable,
            removable,
        ];
    };
};
