import { RDFAdapter } from "../store/RDFAdapter";
import { getContentType, getURL } from "../utilities/responses";
const isRdfLibResponse = (res) => typeof res.req !== "undefined" && typeof res.req.termType !== "undefined";
/**
 * Processes a range of media types with parsers from the
 * [rdflib.js package](https://www.npmjs.com/package/rdflib).
 */
export const createProcessRDF = (rdfParse) => {
    return async function processRDF(response) {
        let data;
        if (isRdfLibResponse(response)) {
            data = response.responseText;
        }
        else if (response instanceof Response) {
            data = response.bodyUsed ? "" : await response.text();
        }
        else if (response instanceof XMLHttpRequest) {
            data = response.responseText;
        }
        else {
            data = response.body;
        }
        const format = getContentType(response);
        const g = new RDFAdapter();
        await new Promise((resolve) => {
            rdfParse(data, g, getURL(response), format, () => {
                resolve();
            });
        });
        return g.quads;
    };
};
