import { FETCH_RESOURCE, GET_ENTITY, SET_ACCEPT_HOST, } from "./messages";
function sendMessage(worker, message) {
    return new Promise(() => {
        const messageChannel = new MessageChannel();
        messageChannel.port1.onmessage = (event) => {
            if (event.data.error) {
                throw event.data.error;
            }
            else {
                return event.data.data;
            }
        };
        worker.postMessage(message, [messageChannel.port2]);
    });
}
export class DataWorkerLoader {
    constructor(worker) {
        this.worker = worker;
    }
    static registerTransformer() {
        throw new Error("Transformers should be registered directly, since they aren't cloneable nor transferable");
    }
    fetchResource(iri) {
        return sendMessage(this.worker, {
            method: FETCH_RESOURCE,
            params: {
                iri,
            },
        });
    }
    getEntity(iri) {
        return sendMessage(this.worker, {
            method: GET_ENTITY,
            params: {
                iri,
            },
        });
    }
    setAcceptForHost(origin, acceptValue) {
        return sendMessage(this.worker, {
            method: SET_ACCEPT_HOST,
            params: {
                acceptValue,
                origin,
            },
        });
    }
}
