import { DataFactory, NamedNode, Quadruple, SomeTerm, Term } from "@ontologies/core";
import { DataRecord, Id } from "./datastrucures/DataSlice";
import { OptionalNamedNode, OptionalNode, OptionalTerm } from "./rdf";
import { RDFAdapter } from "./store/RDFAdapter";
import { DeltaProcessor, SomeNode } from "./types";
export interface RDFStoreOpts {
    data?: Record<Id, DataRecord>;
    deltaProcessorOpts?: {
        [k: string]: NamedNode[];
    };
    innerStore?: RDFAdapter;
}
/**
 * Provides a clean consistent interface to stored (RDF) data.
 */
export declare class RDFStore implements DeltaProcessor {
    langPrefs: string[];
    private changedResources;
    private deltas;
    private deltaProcessor;
    private store;
    get rdfFactory(): DataFactory;
    set rdfFactory(_: DataFactory);
    private defaultGraph;
    constructor({ data, deltaProcessorOpts, innerStore }?: RDFStoreOpts);
    /** @deprecated */
    add(subject: SomeNode, predicate: NamedNode, object: SomeTerm): Quadruple;
    /**
     * Add statements to the store.
     * @param data Data to parse and add to the store.
     * @deprecated
     */
    addQuads(data: Quadruple[]): void;
    /** @deprecated */
    addQuadruples(data: Quadruple[]): Quadruple[];
    /** @deprecated */
    primary(term: SomeNode): SomeNode;
    /**
     * Flushes the change buffer to the return value.
     * @return Statements held in memory since the last flush.
     */
    flush(): Set<string>;
    /** @private */
    getInternalStore(): RDFAdapter;
    references(recordId: SomeNode): Id[];
    /** @deprecated */
    match(subj: OptionalNode, pred: OptionalNamedNode, obj: OptionalTerm, justOne?: boolean): Quadruple[];
    processDelta(delta: Quadruple[]): Quadruple[];
    removeResource(subject: SomeNode): void;
    /** @deprecated */
    removeQuads(statements: Quadruple[]): void;
    /** @deprecated */
    replaceMatches(statements: Quadruple[]): Quadruple[];
    getResourcePropertyRaw(subject: SomeNode, property: SomeNode | SomeNode[]): Quadruple[];
    getResourceProperties<TT extends Term = Term>(subject: SomeNode, property: SomeNode | SomeNode[]): TT[];
    getResourceProperty<T extends Term = Term>(subject: SomeNode, property: SomeNode | SomeNode[]): T | undefined;
    queueDelta(delta: Quadruple[]): void;
    /**
     * Searches the store for all the quads on {iri} (so not all statements relating to {iri}).
     * @param subject The identifier of the resource.
     */
    quadsFor(subject: SomeNode): Quadruple[];
    touch(iri: SomeNode): void;
    workAvailable(): number;
    private handleChange;
}
