import { Id } from "./datastrucures/DataSlice";
import { RDFStore } from "./RDFStore";
import { VocabularyProcessingContext } from "./types";
/**
 * Implements some RDF/OWL logic to enhance the functionality of the property lookups.
 *
 * Basically duplicates some functionality already present in {IndexedFormula} IIRC, but this API should be more
 * optimized so it can be used in real-time by low-power devices as well.
 */
export declare class Schema {
    private static vocabularies;
    private equivalenceSet;
    private expansionCache;
    private liveStore;
    private superMap;
    private processedTypes;
    constructor(liveStore: RDFStore);
    allEquals(recordId: Id, grade?: number): Id[];
    /** @private */
    isInstanceOf(recordId: Id, klass: Id): boolean;
    expand(types: Id[]): Id[];
    getProcessingCtx(): VocabularyProcessingContext<string>;
    /**
     * Expands the given lookupTypes to include all their equivalent and subclasses.
     * This is done in multiple iterations until no new types are found.
     * @param lookupTypes The types to look up. Once given, these are assumed to be classes.
     */
    mineForTypes(lookupTypes: string[]): string[];
    sort(types: string[]): string[];
    /**
     * Returns the hierarchical depth of the type, or -1 if unknown.
     * @param type the type to check
     */
    private superTypeDepth;
    private isSubclassOf;
    private process;
}
