import { NamedNode, Quadruple } from "@ontologies/core";
import { APIFetchOpts, LinkedDataAPI } from "../LinkedDataAPI";
import { DataProcessorOpts, DataTuple, DeltaProcessor, EmptyRequestStatus, LinkedActionResponse, MiddlewareActionHandler, ResourceQueueItem, ResponseTransformer, SomeNode, SomeRequestStatus } from "../types";
export declare const emptyRequest: EmptyRequestStatus;
export declare class DataProcessor implements LinkedDataAPI, DeltaProcessor {
    accept: {
        [k: string]: string;
    };
    private _dispatch?;
    private readonly bulkEndpoint;
    private report;
    private deltas;
    private fetch;
    private readonly invalidationMap;
    private readonly mapping;
    private readonly requestInitGenerator;
    private readonly requestMap;
    private readonly statusMap;
    private readonly store;
    constructor(opts: DataProcessorOpts);
    get dispatch(): MiddlewareActionHandler;
    set dispatch(value: MiddlewareActionHandler);
    execActionByIRI(subject: NamedNode, dataTuple: DataTuple): Promise<LinkedActionResponse>;
    flush(): Set<string>;
    getEntities(resources: ResourceQueueItem[]): Promise<Quadruple[]>;
    /**
     * @see LinkedDataAPI#getEntity
     * @param iri The SomeNode of the entity
     * @param opts The options for fetch-/processing the resource.
     * @param opts The options for fetch-/processing the resource.
     * @return A promise with the resulting entity
     */
    getEntity(iri: NamedNode, opts?: APIFetchOpts): Promise<Quadruple[]>;
    /**
     * @see LinkedDataAPI#getStatus for documentation
     */
    getStatus(iri: NamedNode): SomeRequestStatus;
    invalidate(iri: string | SomeNode, _err?: Error): boolean;
    isInvalid(iri: SomeNode): boolean;
    processExternalResponse(response: Response): Promise<Quadruple[] | undefined>;
    processDelta(delta: Array<Quadruple | void>): Quadruple[];
    /** Register a transformer so it can be used to interact with API's. */
    registerTransformer(transformer: ResponseTransformer, mediaType: string | string[], acceptValue: number): void;
    queueDelta(delta: Quadruple[]): void;
    setAcceptForHost(origin: string, acceptValue: string): void;
    private acceptForHost;
    private execExecHeader;
    private feedResponse;
    private memoizeStatus;
    private clearStatus;
    private requestStatusToJournalStatus;
    private processExecAction;
    private removeInvalidation;
    private serialize;
    private setStatus;
}
