import { NamedNode, Node } from "@ontologies/core";
import { RDFAdapter } from "../store/RDFAdapter";
import { DataObject, DataTuple, NamedBlobTuple, NamespaceMap, ParsedObject, SerializableDataTypes, SomeNode } from "../types";
/**
 * Converts an array to an RDF list-shaped {DataObject} for serialization.
 */
export declare function list(arr: SerializableDataTypes[]): DataObject;
/**
 * Converts an array to an RDF sequence-shaped {DataObject} for serialization.
 */
export declare function seq<T = any>(arr: T[], id?: SomeNode): DataObject;
/** @private */
export declare function processObject(subject: Node, predicate: NamedNode, datum: DataObject | SerializableDataTypes | null | undefined, store: RDFAdapter, ns?: NamespaceMap): NamedBlobTuple[];
export declare function dataToGraphTuple(data: DataObject, ns?: NamespaceMap): DataTuple;
/**
 * Convert a DataObject into a graph. Useful for writing test data in semi-plain JS objects
 * @param iriOrData The data object or an iri for the top-level object.
 * @param data The data object if an IRI was passed.
 * @param store A graph to write the statements into.
 * @param ns Namespace mapping for converting shortened keys.
 */
export declare function toGraph(iriOrData: SomeNode | DataObject, data?: DataObject, store?: RDFAdapter, ns?: NamespaceMap): ParsedObject;
