import { SomeTerm } from "@ontologies/core";
import { DataRecord, DataSlice, FieldSet, Id } from "../datastrucures/DataSlice";
import { DeepRecord } from "../datastrucures/DeepSlice";
import { FieldId, FieldValue } from "../datastrucures/Fields";
import { RecordJournal } from "./RecordJournal";
import { RecordState } from "./RecordState";
import { RecordStatus } from "./RecordStatus";
export declare const idField = "_id";
export declare class StructuredStore {
    private static toSomeNode;
    /**
     * The base URI of the data.
     */
    base: string;
    /** @private */
    data: DataSlice;
    /** @private */
    journal: RecordJournal;
    private aliases;
    /**
     *
     * @param base
     * @param data Will be modified, so don't re-use the reference elsewhere.
     * @param onChange @internal
     */
    constructor(base?: string, data?: DataSlice | undefined, onChange?: (docId: string) => void);
    get recordCount(): number;
    getStatus(recordId: Id): RecordStatus;
    transition(recordId: Id, state: RecordState): void;
    touch(recordId: Id): void;
    deleteRecord(recordId: Id): void;
    getField(recordId: Id, field: FieldId): FieldValue | undefined;
    /**
     * @returns Whether a mutation has occurred.
     */
    setField(recordId: Id, field: FieldId, value: FieldValue): boolean;
    /**
     * Adds a value to a field.
     * @returns Whether a mutation has occurred.
     */
    addField(recordId: Id, field: FieldId, value: SomeTerm): boolean;
    deleteField(recordId: Id, field: FieldId): void;
    deleteFieldMatching(recordId: Id, field: FieldId, value: SomeTerm): void;
    /**
     * Returns the [Id] which is used to store the data under.
     * @internal
     */
    primary<T extends Id | FieldId>(id: T): T;
    /**
     * Find all records which reference this given [recordId]
     */
    references(recordId: Id): Id[];
    /**
     * Sets the {previous} aliased to the topmost alias of {current}.
     * Aliasing only applies to record ids.
     * Any previous alias will be ignored, circular aliasing will be ignored.
     * Blank nodes should not be {current}.
     */
    setAlias(previous: Id, current: Id): void;
    allRecords(): DataRecord[];
    getRecord(recordId: Id): DataRecord | undefined;
    collectRecord(recordId: Id, collected?: Id[]): DeepRecord | undefined;
    setRecord(recordId: Id, fields: FieldSet): DataRecord | undefined;
    private initializeRecord;
}
