import { BlankNode, NamedNode, Quadruple, Term } from "@ontologies/core";
import { SomeNode } from "./types";
/**
 * Filters {obj} to only include statements where the subject equals {predicate}.
 * @param obj The statements to filter.
 * @param predicate The subject to filter for.
 * @return A possibly empty filtered array of statements.
 */
export declare function allRDFPropertyStatements(obj: Quadruple[] | undefined, predicate: SomeNode): Quadruple[];
/**
 * Filters {obj} on subject {predicate} returning the resulting statements' objects.
 * @see allRDFPropertyStatements
 */
export declare function allRDFValues(obj: Quadruple[], predicate: SomeNode): Term[];
/**
 * Resolve {predicate} to any value, if any. If present, additional values are ignored.
 */
export declare function anyRDFValue(obj: Quadruple[] | undefined, predicate: SomeNode): Term | undefined;
export declare function doc<T extends NamedNode | BlankNode>(iri: T): T;
export declare function getPropBestLang<T extends Term = Term>(rawProp: Quadruple[], langPrefs: string[]): T;
export declare function getPropBestLangRaw(statements: Quadruple[], langPrefs: string[]): Quadruple;
export declare function getTermBestLang(rawTerm: Term | Term[], langPrefs: string[]): Term;
export declare function sortByBestLang(statements: Quadruple[], langPrefs: string[]): Quadruple[];
/**
 * Checks if the origin of {href} matches current origin from {window.location}
 * @returns `true` if matches, `false` otherwise.
 */
export declare function isDifferentOrigin(href: SomeNode | string): boolean;
export declare function normalizeType<T1>(type: T1 | T1[]): T1[];
