/**
 * DisjointSet
 * Module port from https://github.com/mljs/disjoint-set/
 */
/**
 * @class DisjointSet
 */
export declare class DisjointSet<T> {
    private nodes;
    constructor();
    /**
     * Adds an element as a new set
     * @param {*} value
     * @return {DisjointSetNode} Object holding the element
     */
    add(value: T): DisjointSetNode<T>;
    allValues(value: T): T[];
    /**
     * Merges the sets that contain x and y
     * @param {DisjointSetNode} x
     * @param {DisjointSetNode} y
     */
    union(x: DisjointSetNode<T>, y: DisjointSetNode<T>): void;
    /**
     * Finds and returns the root node of the set that contains node
     * @param {DisjointSetNode} node
     * @return {DisjointSetNode}
     */
    find(node: DisjointSetNode<T>): DisjointSetNode<T>;
    /**
     * Returns true if x and y belong to the same set
     * @param {DisjointSetNode} x
     * @param {DisjointSetNode} y
     */
    connected(x: DisjointSetNode<T>, y: DisjointSetNode<T>): boolean;
}
export declare class DisjointSetNode<T> {
    parent: DisjointSetNode<T> | null;
    rank: number;
    value: T;
    constructor(value: T);
}
